@@ -5,27 +5,31 @@ __email__ = "e@neural7.io"
 __copyright__ = "Copyright Neural7 2022, Big 5 Personality Traits"
 __credits__ = ["John A. Johnson", "Dhiru Kholia"]
 __license__ = "MIT"
-__version__ = "1.0.0"
+__version__ = "1.5.0"
 __status__ = "production"
 
+import copy
 import uuid
 
 from ipipneo.facet import Facet
 from ipipneo.model import QuestionNumber
 from ipipneo.norm import Norm
-from ipipneo.utility import (apply_invert_select, organize_list_json,
-                             raise_if_age_is_invalid, raise_if_sex_is_invalid)
+from ipipneo.reverse import (ReverseScored120, ReverseScored300,
+                             ReverseScoredCustom)
+from ipipneo.utility import (organize_list_json, raise_if_age_is_invalid,
+                             raise_if_sex_is_invalid)
 
 
 class IpipNeo(Facet):
     """Class that calculates IPIP-NEO answers."""
 
-    def __init__(self, question: int) -> None or BaseException:
+    def __init__(self, question: int, test: bool = False) -> None or BaseException:
         """
         Initialize the class.
 
         Args:
-            - nquestion: Question type.
+            - question: Question type, 120 or 300.
+            - test: Used to test your proposed questions with reverse.
         """
         if question == 120:
             nquestion = QuestionNumber.IPIP_120
@@ -35,28 +39,18 @@ class IpipNeo(Facet):
             raise BaseException(f"Type question {question} is invalid!")
 
         super().__init__(nquestion=nquestion)
-        self._nquestion = question
+        self._nquestion, self._test = (question, test)
 
-    def compute(self, sex: str, age: int, answers: dict) -> dict:
+    def evaluator(self, sex: str, age: int, score: list) -> dict:
         """
-        Compute the answers and generate the dictionary with the results.
+        Apply the calculation of the Big-Five and its personalities based on the answers.
 
         Args:
             - sex: Gender of the individual (M or F).
             - age: The age of the individual.
-            - answers: Standardized dictionary with answers.
+            - score: The normalized score.
         """
-        raise_if_sex_is_invalid(sex=sex)
-        raise_if_age_is_invalid(age=age)
-        assert isinstance(answers, dict), "answers 1 must be a dict"
-
-        answers = apply_invert_select(answers=answers)
-        assert isinstance(answers, dict), "answers 2 must be a dict"
-
-        score = self.score(answers=organize_list_json(answers=answers))
-        assert isinstance(score, list), "score must be a list"
-
-        norm = Norm(sex=sex, age=age)
+        norm = Norm(sex=sex, age=age, nquestion=self._nquestion)
         assert isinstance(norm, dict), "norm must be a dict"
 
         normc = Norm.calc(domain=self.domain(score=score), norm=norm)
@@ -87,6 +81,8 @@ class IpipNeo(Facet):
             "theory": "Big 5 Personality Traits",
             "model": "IPIP-NEO",
             "question": self._nquestion,
+            "test": self._test,
+            "version": __version__,
             "person": {
                 "sex": sex,
                 "age": age,
@@ -101,3 +97,46 @@ class IpipNeo(Facet):
                 },
             },
         }
+
+    def compute(self, sex: str, age: int, answers: dict, compare: bool = False) -> dict:
+        """
+        Compute the answers and generate the data with the results.
+
+        Args:
+            - sex: Gender of the individual (M or F).
+            - age: The age of the individual.
+            - answers: Standardized dictionary with answers.
+            - compare: If true, it shows the user's answers and reverse score.
+        """
+        raise_if_sex_is_invalid(sex=sex)
+        raise_if_age_is_invalid(age=age)
+        assert isinstance(answers, dict), "answers must be a dict"
+
+        original = copy.deepcopy(answers)
+        assert isinstance(original, dict), "original must be a dict"
+
+        reversed = {}
+        if self._test:
+            reversed = ReverseScoredCustom(answers=answers)
+        else:
+            reversed = (
+                ReverseScored120(answers=answers)
+                if self._nquestion == 120
+                else ReverseScored300(answers=answers)
+            )
+        assert isinstance(reversed, dict), "reversed must be a dict"
+
+        score = self.score(answers=organize_list_json(answers=reversed))
+        assert isinstance(score, list), "score must be a list"
+
+        result = self.evaluator(sex=sex, age=age, score=score)
+        assert isinstance(result, dict), "result 1 must be a dict"
+
+        if compare:
+            result["person"]["result"]["compare"] = {
+                "user_answers_original": original.get("answers", []),
+                "user_answers_reversed": reversed.get("answers", []),
+            }
+        assert isinstance(result, dict), "result 2 must be a dict"
+
+        return result or {}
